@@ -167,14 +167,14 @@ int main(int argc, char *argv[])
     rate = bytes / 1024 * G_MSEC_PER_SEC / (end - start);
     printf("* %.3f ms for %d bytes\n", elapsed, bytes);
     printf("* %d KiB/s\n", rate);
-    printf("\n");
+    printf("\n\n");
 
     printf("READ AND WRITE REGISTERS\n\n");
 
     nb_points = MODBUS_MAX_RW_WRITE_REGISTERS;
     start = gettime_ms();
     for (i=0; i<n_loop; i++) {
-        rc = modbus_read_and_write_registers(ctx,
+        rc = modbus_write_and_read_registers(ctx,
                                              0, nb_points, tab_reg,
                                              0, nb_points, tab_reg);
         if (rc == -1) {
